@@ -114,6 +114,22 @@ module Grape
       end
 
       attr_writer :formatters
+
+      def hash_access
+        @hash_access ||= :to_sym
+      end
+
+      def hash_access=(value)
+        @hash_access =
+          case value
+          when :to_s, :str, :string
+            :to_s
+          when :to_sym, :sym, :symbol
+            :to_sym
+          else
+            :to_sym
+          end
+      end
     end
 
     @formatters = {}
@@ -168,18 +184,23 @@ module Grape
     # @option options :documentation Define documenation for an exposed
     #   field, typically the value is a hash with two fields, type and desc.
     # @option options :merge This option allows you to merge an exposed field to the root
+    #
+    # rubocop:disable Layout/LineLength
     def self.expose(*args, &block)
       options = merge_options(args.last.is_a?(Hash) ? args.pop : {})
 
       if args.size > 1
+
         raise ArgumentError, 'You may not use the :as option on multi-attribute exposures.' if options[:as]
         raise ArgumentError, 'You may not use the :expose_nil on multi-attribute exposures.' if options.key?(:expose_nil)
         raise ArgumentError, 'You may not use block-setting on multi-attribute exposures.' if block_given?
       end
 
-      raise ArgumentError, 'You may not use block-setting when also using format_with' if block_given? && options[:format_with].respond_to?(:call)
-
       if block_given?
+        if options[:format_with].respond_to?(:call)
+          raise ArgumentError, 'You may not use block-setting when also using format_with'
+        end
+
         if block.parameters.any?
           options[:proc] = block
         else
@@ -191,6 +212,7 @@ module Grape
       @nesting_stack ||= []
       args.each { |attribute| build_exposure_for_attribute(attribute, @nesting_stack, options, block) }
     end
+    # rubocop:enable Layout/LineLength
 
     def self.build_exposure_for_attribute(attribute, nesting_stack, options, block)
       exposure_list = nesting_stack.empty? ? root_exposures : nesting_stack.last.nested_exposures
@@ -291,6 +313,7 @@ module Grape
     #
     def self.format_with(name, &block)
       raise ArgumentError, 'You must pass a block for formatters' unless block_given?
+
       formatters[name.to_sym] = block
     end
 
@@ -454,8 +477,8 @@ module Grape
 
     def initialize(object, options = {})
       @object = object
-      @delegator = Delegator.new(object)
       @options = options.is_a?(Options) ? options : Options.new(options)
+      @delegator = Delegator.new(object)
     end
 
     def root_exposures
@@ -506,28 +529,50 @@ module Grape
     end
 
     def delegate_attribute(attribute)
-      if respond_to?(attribute, true) && Grape::Entity > method(attribute).owner
+      if is_defined_in_entity?(attribute)
         send(attribute)
       else
-        delegator.delegate(attribute)
+        delegator.delegate(attribute, hash_access: self.class.hash_access)
       end
     end
 
+    def is_defined_in_entity?(attribute)
+      return false unless respond_to?(attribute, true)
+
+      ancestors = self.class.ancestors
+      ancestors.index(Grape::Entity) > ancestors.index(method(attribute).owner)
+    end
+
     alias as_json serializable_hash
 
     def to_json(options = {})
-      options = options.to_h if options && options.respond_to?(:to_h)
+      options = options.to_h if options&.respond_to?(:to_h)
       MultiJson.dump(serializable_hash(options))
     end
 
     def to_xml(options = {})
-      options = options.to_h if options && options.respond_to?(:to_h)
+      options = options.to_h if options&.respond_to?(:to_h)
       serializable_hash(options).to_xml(options)
     end
 
     # All supported options.
     OPTIONS = %i[
-      rewrite as if unless using with proc documentation format_with safe attr_path if_extras unless_extras merge expose_nil override
+      rewrite
+      as
+      if
+      unless
+      using
+      with
+      proc
+      documentation
+      format_with
+      safe
+      attr_path
+      if_extras
+      unless_extras
+      merge
+      expose_nil
+      override
     ].to_set.freeze
 
     # Merges the given options with current block options.
